diff --git a/index.html b/index.html
index 62fc52e..67dc1be 100644
--- a/index.html
+++ b/index.html
@@ -108,12 +108,12 @@
Shortcuts
Glowing Bear has a few shortcuts:
- - ALT+n: Toggle nicklist
- - ALT+l: Focus on input bar
+ - ALT-n: Toggle nicklist
+ - ALT-l: Focus on input bar
- ALT-[0-9]: Focus on buffer
- ALT-a: Focus on next buffer with activity
- ALT-<: Switch to previous buffer
- - CTRL+G: Focus on buffer list filter
+ - ALT-g: Focus on buffer list filter
- escape: disconnect
- arrow keys: history navigation
@@ -279,7 +279,7 @@ $ openssl req -nodes -newkey rsa:4096 -keyout relay.pem -x509 -days 365 -out rel
-
+
diff --git a/js/glowingbear.js b/js/glowingbear.js
index 8b075e8..811c0e7 100644
--- a/js/glowingbear.js
+++ b/js/glowingbear.js
@@ -856,7 +856,9 @@ weechat.controller('WeechatCtrl', ['$rootScope', '$scope', '$store', '$timeout',
} // Handle enter
else if (code === 13) {
$event.preventDefault();
- // TODO Switch to first matching buffer and reset query
+ if ($scope.filteredBuffers.length > 0) {
+ models.setActiveBuffer($scope.filteredBuffers[0].id);
+ }
$scope.search = '';
}
};
@@ -1056,8 +1058,8 @@ weechat.directive('inputBar', function() {
return true;
}
- // Ctrl+G -> focus on buffer filter input
- if ($event.ctrlKey && (code === 103 || code === 71)) {
+ // Alt+G -> focus on buffer filter input
+ if ($event.altKey && (code === 103 || code === 71)) {
$event.preventDefault();
document.getElementById('bufferFilter').focus();
return true;